Class: VagrantPlugins::OpenStack::Action::SyncFolders
- Inherits:
-
Object
- Object
- VagrantPlugins::OpenStack::Action::SyncFolders
- Defined in:
- lib/vagrant-openstack-plugin/action/sync_folders.rb
Overview
This middleware uses rsync to sync the folders over to the remote instance.
Instance Method Summary collapse
- #call(env) ⇒ Object
-
#initialize(app, env) ⇒ SyncFolders
constructor
A new instance of SyncFolders.
Constructor Details
#initialize(app, env) ⇒ SyncFolders
11 12 13 14 |
# File 'lib/vagrant-openstack-plugin/action/sync_folders.rb', line 11 def initialize(app, env) @app = app @logger = Log4r::Logger.new("vagrant_openstack::action::sync_folders") end |
Instance Method Details
#call(env) ⇒ Object
16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/vagrant-openstack-plugin/action/sync_folders.rb', line 16 def call(env) @app.call(env) ssh_info = env[:machine].ssh_info env[:machine].config.vm.synced_folders.each do |id, data| # ignore disabled shared folders if data[:disabled] @logger.info "Not syncing disabled folder: #{data[:hostpath]} => #{data[:guestpath]}" next end hostpath = File.(data[:hostpath], env[:root_path]) guestpath = data[:guestpath] # Make sure there is a trailing slash on the host path to # avoid creating an additional directory with rsync hostpath = "#{hostpath}/" if hostpath !~ /\/$/ env[:ui].info(I18n.t("vagrant_openstack.rsync_folder", :hostpath => hostpath, :guestpath => guestpath)) # Create the guest path # Use sudo only when it is necessary cmd_mkdir = "mkdir -p '#{guestpath}'" cmd_chown = "chown #{ssh_info[:username]} '#{guestpath}'" if env[:machine].communicate.execute(cmd_mkdir, :error_check => false) != 0 then env[:machine].communicate.sudo(cmd_mkdir) end if env[:machine].communicate.execute(cmd_chown, :error_check => false) != 0 then env[:machine].communicate.sudo(cmd_chown) end #collect rsync excludes specified :rsync_excludes=>['path1',...] in synced_folder options excludes = ['.vagrant/', 'Vagrantfile', *Array(data[:rsync_excludes])].uniq # Rsync over to the guest path using the SSH info if env[:machine].config.ssh.proxy_command proxy_cmd = "-o ProxyCommand='#{env[:machine].config.ssh.proxy_command}'" else proxy_cmd = '' end # poor workaround for poor ipv6 handling of rsync if ssh_info[:host].include? ':' user_at_host = "[#{ssh_info[:username]}@#{ssh_info[:host]}]" else user_at_host = ssh_info[:username] + "@" + ssh_info[:host] end command = [ 'rsync', '--verbose', '--archive', '-z', '--delete', *excludes.map{|e|['--exclude', e]}.flatten, '-e', "ssh -p #{ssh_info[:port]} -o StrictHostKeyChecking=no #{proxy_cmd} #{(ssh_info)}", hostpath, user_at_host + ":" + guestpath] r = Vagrant::Util::Subprocess.execute(*command) if r.exit_code != 0 raise Errors::RsyncError, :guestpath => guestpath, :hostpath => hostpath, :stderr => r.stderr end end end |